// -----------------------------------------------------------------------------
// File name: fnt68.h
// Author: Roberto Fonseca Iannini
// E-mail: beto1684@yahoo.com.br
// -----------------------------------------------------------------------------
// REVISION HISTORY
// VER     DATE                   DESCRIPTION
// 0.1  20 jan 2006   ANSI font
// -----------------------------------------------------------------------------
// USAGE: -Eeach char is 8 bits wide and 8 bytes height
//        -Bytes are LSB first, i.e., compliant w/ graph mode for the HD61830 &
//         others
//        -Implemented       chars        decimal
//                    +----------------+----------+
//                    |     (space)    |    32    |
//                    |        !       |    33    |
//                    |        "       |    34    |
//                    |        #       |    35    |
//                    |        $       |    36    |
//                    |                |          |
//                    |              until        |
//                    |                |          |
//                    |               |   253    |<---- these chars many not
//                    |               |   254    |      show in some text
//                    |               |   255    |      editors... but they
//                    +----------------+----------+      will appear in the LCD
//
//        -When reading a byte, pay attention to plot only the six left aligned
//         bits or plot the byte and return xposition 2 pixels back
// -----------------------------------------------------------------------------
// REUSE ISSUES
// This file can be used as a font source for many LCD controllers. Enjoy it.
// -----------------------------------------------------------------------------

#define FNT68_HEIGHT 8
#define FNT68_WIDTH  8

const unsigned char fnt68[] = {

0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x1F,  /*  &&&&&...  */
0x0A,  /*  .&.&....  */
0x1F,  /*  &&&&&...  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x1E,  /*  .&&&&...  */
0x05,  /*  &.&.....  */
0x0E,  /*  .&&&....  */
0x14,  /*  ..&.&...  */
0x0F,  /*  &&&&....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x03,  /*  &&......  */
0x13,  /*  &&..&...  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x19,  /*  &..&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x02,  /*  .&......  */
0x05,  /*  &.&.....  */
0x05,  /*  &.&.....  */
0x02,  /*  .&......  */
0x15,  /*  &.&.&...  */
0x09,  /*  &..&....  */
0x16,  /*  .&&.&...  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x02,  /*  .&......  */
0x02,  /*  .&......  */
0x04,  /*  ..&.....  */
0x08,  /*  ...&....  */
0x00,  /*  ........  */
0x02,  /*  .&......  */
0x04,  /*  ..&.....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x15,  /*  &.&.&...  */
0x0E,  /*  .&&&....  */
0x0E,  /*  .&&&....  */
0x15,  /*  &.&.&...  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x1F,  /*  &&&&&...  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x15,  /*  &.&.&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x06,  /*  .&&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x10,  /*  ....&...  */
0x0E,  /*  .&&&....  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x10,  /*  ....&...  */
0x08,  /*  ...&....  */
0x0C,  /*  ..&&....  */
0x10,  /*  ....&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x08,  /*  ...&....  */
0x0C,  /*  ..&&....  */
0x0A,  /*  .&.&....  */
0x09,  /*  &..&....  */
0x1F,  /*  &&&&&...  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x01,  /*  &.......  */
0x0F,  /*  &&&&....  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x02,  /*  .&......  */
0x01,  /*  &.......  */
0x0F,  /*  &&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x1E,  /*  .&&&&...  */
0x10,  /*  ....&...  */
0x08,  /*  ...&....  */
0x07,  /*  &&&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x04,  /*  ..&.....  */
0x08,  /*  ...&....  */
0x10,  /*  ....&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x02,  /*  .&......  */
0x04,  /*  ..&.....  */
0x08,  /*  ...&....  */
0x10,  /*  ....&...  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x10,  /*  ....&...  */
0x0C,  /*  ..&&....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x15,  /*  &.&.&...  */
0x1D,  /*  &.&&&...  */
0x0D,  /*  &.&&....  */
0x01,  /*  &.......  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x0F,  /*  &&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0F,  /*  &&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0F,  /*  &&&&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x0F,  /*  &&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0F,  /*  &&&&....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x0F,  /*  &&&&....  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x0F,  /*  &&&&....  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x11,  /*  &...&...  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x19,  /*  &..&&...  */
0x11,  /*  &...&...  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x09,  /*  &..&....  */
0x06,  /*  .&&.....  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x09,  /*  &..&....  */
0x05,  /*  &.&.....  */
0x03,  /*  &&......  */
0x05,  /*  &.&.....  */
0x09,  /*  &..&....  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x1B,  /*  &&.&&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x13,  /*  &&..&...  */
0x15,  /*  &.&.&...  */
0x19,  /*  &..&&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x0F,  /*  &&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0F,  /*  &&&&....  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x15,  /*  &.&.&...  */
0x09,  /*  &..&....  */
0x16,  /*  .&&.&...  */
0x00,  /*  ........  */
0x0F,  /*  &&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0F,  /*  &&&&....  */
0x05,  /*  &.&.....  */
0x09,  /*  &..&....  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x01,  /*  &.......  */
0x0E,  /*  .&&&....  */
0x10,  /*  ....&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x15,  /*  &.&.&...  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x0A,  /*  .&.&....  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x10,  /*  ....&...  */
0x08,  /*  ...&....  */
0x0E,  /*  .&&&....  */
0x02,  /*  .&......  */
0x01,  /*  &.......  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x02,  /*  .&......  */
0x02,  /*  .&......  */
0x02,  /*  .&......  */
0x02,  /*  .&......  */
0x02,  /*  .&......  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x01,  /*  &.......  */
0x02,  /*  .&......  */
0x04,  /*  ..&.....  */
0x08,  /*  ...&....  */
0x10,  /*  ....&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x04,  /*  ..&.....  */
0x08,  /*  ...&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x08,  /*  ...&....  */
0x0E,  /*  .&&&....  */
0x09,  /*  &..&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x0D,  /*  &.&&....  */
0x13,  /*  &&..&...  */
0x11,  /*  &...&...  */
0x13,  /*  &&..&...  */
0x0D,  /*  &.&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x01,  /*  &.......  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x16,  /*  .&&.&...  */
0x19,  /*  &..&&...  */
0x11,  /*  &...&...  */
0x19,  /*  &..&&...  */
0x16,  /*  .&&.&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x01,  /*  &.......  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x08,  /*  ...&....  */
0x14,  /*  ..&.&...  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x19,  /*  &..&&...  */
0x19,  /*  &..&&...  */
0x16,  /*  .&&.&...  */
0x10,  /*  ....&...  */
0x0E,  /*  .&&&....  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x0D,  /*  &.&&....  */
0x13,  /*  &&..&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x08,  /*  ...&....  */
0x00,  /*  ........  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x09,  /*  &..&....  */
0x06,  /*  .&&.....  */
0x00,  /*  ........  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x09,  /*  &..&....  */
0x05,  /*  &.&.....  */
0x03,  /*  &&......  */
0x05,  /*  &.&.....  */
0x09,  /*  &..&....  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0B,  /*  &&.&....  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0D,  /*  &.&&....  */
0x13,  /*  &&..&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0D,  /*  &.&&....  */
0x13,  /*  &&..&...  */
0x13,  /*  &&..&...  */
0x0D,  /*  &.&&....  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x16,  /*  .&&.&...  */
0x19,  /*  &..&&...  */
0x19,  /*  &..&&...  */
0x16,  /*  .&&.&...  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0D,  /*  &.&&....  */
0x13,  /*  &&..&...  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x01,  /*  &.......  */
0x0E,  /*  .&&&....  */
0x10,  /*  ....&...  */
0x0F,  /*  &&&&....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x1F,  /*  &&&&&...  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x14,  /*  ..&.&...  */
0x08,  /*  ...&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x19,  /*  &..&&...  */
0x16,  /*  .&&.&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x0A,  /*  .&.&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x1E,  /*  .&&&&...  */
0x10,  /*  ....&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x08,  /*  ...&....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x02,  /*  .&......  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x00,  /*  ........  */
0x02,  /*  .&......  */
0x15,  /*  &.&.&...  */
0x08,  /*  ...&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x1B,  /*  &&.&&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x16,  /*  .&&.&...  */
0x09,  /*  &..&....  */
0x09,  /*  &..&....  */
0x09,  /*  &..&....  */
0x16,  /*  .&&.&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x19,  /*  &..&&...  */
0x0F,  /*  &&&&....  */
0x19,  /*  &..&&...  */
0x0F,  /*  &&&&....  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x19,  /*  &..&&...  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x11,  /*  &...&...  */
0x02,  /*  .&......  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x09,  /*  &..&....  */
0x09,  /*  &..&....  */
0x09,  /*  &..&....  */
0x06,  /*  .&&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x16,  /*  .&&.&...  */
0x03,  /*  &&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x05,  /*  &.&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x04,  /*  ..&.....  */
0x1F,  /*  &&&&&...  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x1B,  /*  &&.&&...  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x02,  /*  .&......  */
0x0C,  /*  ..&&....  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x0E,  /*  .&&&....  */
0x19,  /*  &..&&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x13,  /*  &&..&...  */
0x0E,  /*  .&&&....  */
0x01,  /*  &.......  */
0x0E,  /*  .&&&....  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x0F,  /*  &&&&....  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x08,  /*  ...&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x04,  /*  ..&.....  */
0x08,  /*  ...&....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x14,  /*  ..&.&...  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x05,  /*  &.&.....  */
0x05,  /*  &.&.....  */
0x07,  /*  &&&.....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x3F,  /*  &&&&&&..  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x17,  /*  &&&.&...  */
0x1D,  /*  &.&&&...  */
0x00,  /*  ........  */
0x17,  /*  &&&.&...  */
0x1D,  /*  &.&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x1B,  /*  &&.&&...  */
0x1B,  /*  &&.&&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x05,  /*  &.&.....  */
0x05,  /*  &.&.....  */
0x06,  /*  .&&.....  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x1E,  /*  .&&&&...  */
0x1E,  /*  .&&&&...  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x07,  /*  &&&.....  */
0x09,  /*  &..&....  */
0x09,  /*  &..&....  */
0x07,  /*  &&&.....  */
0x09,  /*  &..&....  */
0x1D,  /*  &.&&&...  */
0x09,  /*  &..&....  */
0x09,  /*  &..&....  */
0x18,  /*  ...&&...  */
0x14,  /*  ..&.&...  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x05,  /*  &.&.....  */
0x03,  /*  &&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x01,  /*  &.......  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x04,  /*  ..&.....  */
0x0C,  /*  ..&&....  */
0x1A,  /*  .&.&&...  */
0x12,  /*  .&..&...  */
0x07,  /*  &&&.....  */
0x02,  /*  .&......  */
0x12,  /*  .&..&...  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1B,  /*  &&.&&...  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x0A,  /*  .&.&....  */
0x04,  /*  ..&.....  */
0x1B,  /*  &&.&&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x1F,  /*  &&&&&...  */
0x04,  /*  ..&.....  */
0x1F,  /*  &&&&&...  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x12,  /*  .&..&...  */
0x0A,  /*  .&.&....  */
0x14,  /*  ..&.&...  */
0x08,  /*  ...&....  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x0C,  /*  ..&&....  */
0x14,  /*  ..&.&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x21,  /*  &....&..  */
0x2D,  /*  &.&&.&..  */
0x25,  /*  &.&..&..  */
0x25,  /*  &.&..&..  */
0x2D,  /*  &.&&.&..  */
0x21,  /*  &....&..  */
0x1E,  /*  .&&&&...  */
0x0E,  /*  .&&&....  */
0x09,  /*  &..&....  */
0x09,  /*  &..&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x24,  /*  ..&..&..  */
0x12,  /*  .&..&...  */
0x09,  /*  &..&....  */
0x12,  /*  .&..&...  */
0x24,  /*  ..&..&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x21,  /*  &....&..  */
0x2D,  /*  &.&&.&..  */
0x2D,  /*  &.&&.&..  */
0x25,  /*  &.&..&..  */
0x2D,  /*  &.&&.&..  */
0x21,  /*  &....&..  */
0x1E,  /*  .&&&&...  */
0x3F,  /*  &&&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x1B,  /*  &&.&&...  */
0x1B,  /*  &&.&&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x1F,  /*  &&&&&...  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x06,  /*  .&&.....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x04,  /*  ..&.....  */
0x02,  /*  .&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x1A,  /*  .&.&&...  */
0x16,  /*  .&&.&...  */
0x01,  /*  &.......  */
0x1E,  /*  .&&&&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x16,  /*  .&&.&...  */
0x14,  /*  ..&.&...  */
0x14,  /*  ..&.&...  */
0x14,  /*  ..&.&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x08,  /*  ...&....  */
0x06,  /*  .&&.....  */
0x0C,  /*  ..&&....  */
0x0E,  /*  .&&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x09,  /*  &..&....  */
0x12,  /*  .&..&...  */
0x24,  /*  ..&..&..  */
0x12,  /*  .&..&...  */
0x09,  /*  &..&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x01,  /*  &.......  */
0x11,  /*  &...&...  */
0x09,  /*  &..&....  */
0x15,  /*  &.&.&...  */
0x1A,  /*  .&.&&...  */
0x1D,  /*  &.&&&...  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x01,  /*  &.......  */
0x11,  /*  &...&...  */
0x09,  /*  &..&....  */
0x1D,  /*  &.&&&...  */
0x12,  /*  .&..&...  */
0x19,  /*  &..&&...  */
0x04,  /*  ..&.....  */
0x1C,  /*  ..&&&...  */
0x03,  /*  &&......  */
0x22,  /*  .&...&..  */
0x13,  /*  &&..&...  */
0x2A,  /*  .&.&.&..  */
0x35,  /*  &.&.&&..  */
0x3A,  /*  .&.&&&..  */
0x20,  /*  .....&..  */
0x20,  /*  .....&..  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x06,  /*  .&&.....  */
0x01,  /*  &.......  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x07,  /*  &&&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x16,  /*  .&&.&...  */
0x0D,  /*  &.&&....  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x3C,  /*  ..&&&&..  */
0x0A,  /*  .&.&....  */
0x09,  /*  &..&....  */
0x1F,  /*  &&&&&...  */
0x09,  /*  &..&....  */
0x09,  /*  &..&....  */
0x39,  /*  &..&&&..  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x08,  /*  ...&....  */
0x06,  /*  .&&.....  */
0x03,  /*  &&......  */
0x00,  /*  ........  */
0x0F,  /*  &&&&....  */
0x01,  /*  &.......  */
0x07,  /*  &&&.....  */
0x01,  /*  &.......  */
0x0F,  /*  &&&&....  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x0F,  /*  &&&&....  */
0x01,  /*  &.......  */
0x07,  /*  &&&.....  */
0x01,  /*  &.......  */
0x0F,  /*  &&&&....  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x09,  /*  &..&....  */
0x0F,  /*  &&&&....  */
0x01,  /*  &.......  */
0x07,  /*  &&&.....  */
0x01,  /*  &.......  */
0x0F,  /*  &&&&....  */
0x00,  /*  ........  */
0x09,  /*  &..&....  */
0x00,  /*  ........  */
0x0F,  /*  &&&&....  */
0x01,  /*  &.......  */
0x07,  /*  &&&.....  */
0x01,  /*  &.......  */
0x0F,  /*  &&&&....  */
0x00,  /*  ........  */
0x07,  /*  &&&.....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x0A,  /*  .&.&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x17,  /*  &&&.&...  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x13,  /*  &&..&...  */
0x17,  /*  &&&.&...  */
0x1D,  /*  &.&&&...  */
0x19,  /*  &..&&...  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x07,  /*  &&&.....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x16,  /*  .&&.&...  */
0x0D,  /*  &.&&....  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x2E,  /*  .&&&.&..  */
0x19,  /*  &..&&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x15,  /*  &.&.&...  */
0x13,  /*  &&..&...  */
0x0E,  /*  .&&&....  */
0x01,  /*  &.......  */
0x07,  /*  &&&.....  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x0A,  /*  .&.&....  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x07,  /*  &&&.....  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0A,  /*  .&.&....  */
0x04,  /*  ..&.....  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x01,  /*  &.......  */
0x0D,  /*  &.&&....  */
0x13,  /*  &&..&...  */
0x13,  /*  &&..&...  */
0x0D,  /*  &.&&....  */
0x01,  /*  &.......  */
0x07,  /*  &&&.....  */
0x09,  /*  &..&....  */
0x09,  /*  &..&....  */
0x07,  /*  &&&.....  */
0x09,  /*  &..&....  */
0x11,  /*  &...&...  */
0x0D,  /*  &.&&....  */
0x00,  /*  ........  */
0x03,  /*  &&......  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x08,  /*  ...&....  */
0x0E,  /*  .&&&....  */
0x09,  /*  &..&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x08,  /*  ...&....  */
0x0E,  /*  .&&&....  */
0x09,  /*  &..&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x06,  /*  .&&.....  */
0x08,  /*  ...&....  */
0x0E,  /*  .&&&....  */
0x09,  /*  &..&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x16,  /*  .&&.&...  */
0x0D,  /*  &.&&....  */
0x06,  /*  .&&.....  */
0x08,  /*  ...&....  */
0x0E,  /*  .&&&....  */
0x09,  /*  &..&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x08,  /*  ...&....  */
0x0E,  /*  .&&&....  */
0x09,  /*  &..&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x08,  /*  ...&....  */
0x0E,  /*  .&&&....  */
0x09,  /*  &..&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3E,  /*  .&&&&&..  */
0x08,  /*  ...&....  */
0x1E,  /*  .&&&&...  */
0x09,  /*  &..&....  */
0x3E,  /*  .&&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x03,  /*  &&......  */
0x03,  /*  &&......  */
0x1E,  /*  .&&&&...  */
0x08,  /*  ...&....  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x03,  /*  &&......  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x01,  /*  &.......  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x01,  /*  &.......  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x01,  /*  &.......  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x1F,  /*  &&&&&...  */
0x01,  /*  &.......  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x12,  /*  .&..&...  */
0x0C,  /*  ..&&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x14,  /*  ..&.&...  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x08,  /*  ...&....  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x1F,  /*  &&&&&...  */
0x06,  /*  .&&.....  */
0x09,  /*  &..&....  */
0x11,  /*  &...&...  */
0x19,  /*  &..&&...  */
0x16,  /*  .&&.&...  */
0x00,  /*  ........  */
0x16,  /*  .&&.&...  */
0x0D,  /*  &.&&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x03,  /*  &&......  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x16,  /*  .&&.&...  */
0x0D,  /*  &.&&....  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x04,  /*  ..&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x2E,  /*  .&&&.&..  */
0x19,  /*  &..&&...  */
0x15,  /*  &.&.&...  */
0x13,  /*  &&..&...  */
0x0E,  /*  .&&&....  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x03,  /*  &&......  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x19,  /*  &..&&...  */
0x16,  /*  .&&.&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x19,  /*  &..&&...  */
0x16,  /*  .&&.&...  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x19,  /*  &..&&...  */
0x16,  /*  .&&.&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x00,  /*  ........  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x19,  /*  &..&&...  */
0x16,  /*  .&&.&...  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x1C,  /*  ..&&&...  */
0x10,  /*  ....&...  */
0x0E,  /*  .&&&....  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x0F,  /*  &&&&....  */
0x11,  /*  &...&...  */
0x11,  /*  &...&...  */
0x0F,  /*  &&&&....  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x12,  /*  .&..&...  */
0x00,  /*  ........  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x12,  /*  .&..&...  */
0x1C,  /*  ..&&&...  */
0x10,  /*  ....&...  */
0x0E   /*  .&&&....  */
};
