// -----------------------------------------------------------------------------
// File name: fnt816.h
// Author: Roberto Fonseca Iannini
// E-mail: beto1684@yahoo.com.br
// -----------------------------------------------------------------------------
// REVISION HISTORY
// VER     DATE                   DESCRIPTION
// 0.1  20 jan 2006   ANSI font
// -----------------------------------------------------------------------------
// USAGE: -Eeach char is 8 bits wide and 16 bytes height
//        -Bytes are LSB first, i.e., compliant w/ graph mode for the HD61830 &
//         others
//        -Implemented       chars        decimal
//                    +----------------+----------+
//                    |     (space)    |    32    |
//                    |        !       |    33    |
//                    |        "       |    34    |
//                    |        #       |    35    |
//                    |        $       |    36    |
//                    |                |          |
//                    |              until        |
//                    |                |          |
//                    |               |   253    |<---- these chars many not
//                    |               |   254    |      show in some text
//                    |               |   255    |      editors... but they
//                    +----------------+----------+      will appear in the LCD
//
// -----------------------------------------------------------------------------
// REUSE ISSUES
// This file can be used as a font source for many LCD controllers. Enjoy it.
// -----------------------------------------------------------------------------

#define FNT816_HEIGHT 16
#define FNT816_WIDTH  8

const unsigned char fnt816[] = {

0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x3C,  /*  ..&&&&..  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x44,  /*  ..&...&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0xFE,  /*  .&&&&&&&  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0xFE,  /*  .&&&&&&&  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0x86,  /*  .&&....&  */
0x06,  /*  .&&.....  */
0x7C,  /*  ..&&&&&.  */
0xC0,  /*  ......&&  */
0xC0,  /*  ......&&  */
0xC2,  /*  .&....&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x86,  /*  .&&....&  */
0xC6,  /*  .&&...&&  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0xCC,  /*  ..&&..&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0xDC,  /*  ..&&&.&&  */
0x76,  /*  .&&.&&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x06,  /*  .&&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x42,  /*  .&....&.  */
0x66,  /*  .&&..&&.  */
0x3C,  /*  ..&&&&..  */
0xFF,  /*  &&&&&&&&  */
0x3C,  /*  ..&&&&..  */
0x66,  /*  .&&..&&.  */
0x42,  /*  .&....&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0xFF,  /*  &&&&&&&&  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFF,  /*  &&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x80,  /*  .......&  */
0xC0,  /*  ......&&  */
0xE0,  /*  .....&&&  */
0x70,  /*  ....&&&.  */
0x38,  /*  ...&&&..  */
0x1C,  /*  ..&&&...  */
0x0E,  /*  .&&&....  */
0x07,  /*  &&&.....  */
0x03,  /*  &&......  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x38,  /*  ...&&&..  */
0x3C,  /*  ..&&&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0xFC,  /*  ..&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC0,  /*  ......&&  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x86,  /*  .&&....&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC0,  /*  ......&&  */
0xC0,  /*  ......&&  */
0x78,  /*  ...&&&&.  */
0xC0,  /*  ......&&  */
0xC0,  /*  ......&&  */
0xC0,  /*  ......&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x60,  /*  .....&&.  */
0x70,  /*  ....&&&.  */
0x78,  /*  ...&&&&.  */
0x6C,  /*  ..&&.&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xFE,  /*  .&&&&&&&  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0xF0,  /*  ....&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x7E,  /*  .&&&&&&.  */
0xC0,  /*  ......&&  */
0xC0,  /*  ......&&  */
0xC6,  /*  .&&...&&  */
0xCE,  /*  .&&&..&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x0C,  /*  ..&&....  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x7E,  /*  .&&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0xC6,  /*  .&&...&&  */
0xC0,  /*  ......&&  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFC,  /*  ..&&&&&&  */
0xC0,  /*  ......&&  */
0xC0,  /*  ......&&  */
0x60,  /*  .....&&.  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x06,  /*  .&&.....  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x60,  /*  .....&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7E,  /*  .&&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7E,  /*  .&&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x06,  /*  .&&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xF6,  /*  .&&.&&&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0x76,  /*  .&&.&&&.  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7E,  /*  .&&&&&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x7C,  /*  ..&&&&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x7E,  /*  .&&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x78,  /*  ...&&&&.  */
0xCC,  /*  ..&&..&&  */
0x86,  /*  .&&....&  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x86,  /*  .&&....&  */
0xCC,  /*  ..&&..&&  */
0x78,  /*  ...&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3E,  /*  .&&&&&..  */
0x6C,  /*  ..&&.&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x6C,  /*  ..&&.&&.  */
0x3E,  /*  .&&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0xCC,  /*  ..&&..&&  */
0x8C,  /*  ..&&...&  */
0x2C,  /*  ..&&.&..  */
0x3C,  /*  ..&&&&..  */
0x2C,  /*  ..&&.&..  */
0x0C,  /*  ..&&....  */
0x8C,  /*  ..&&...&  */
0xCC,  /*  ..&&..&&  */
0xFE,  /*  .&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0xCC,  /*  ..&&..&&  */
0x8C,  /*  ..&&...&  */
0x2C,  /*  ..&&.&..  */
0x3C,  /*  ..&&&&..  */
0x2C,  /*  ..&&.&..  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x78,  /*  ...&&&&.  */
0xCC,  /*  ..&&..&&  */
0x86,  /*  .&&....&  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0xF6,  /*  .&&.&&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xEC,  /*  ..&&.&&&  */
0xB8,  /*  ...&&&.&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xF0,  /*  ....&&&&  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xCE,  /*  .&&&..&&  */
0xCC,  /*  ..&&..&&  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0x3C,  /*  ..&&&&..  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCE,  /*  .&&&..&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x8C,  /*  ..&&...&  */
0xCC,  /*  ..&&..&&  */
0xFE,  /*  .&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xEE,  /*  .&&&.&&&  */
0xFE,  /*  .&&&&&&&  */
0xD6,  /*  .&&.&.&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xCE,  /*  .&&&..&&  */
0xDE,  /*  .&&&&.&&  */
0xFE,  /*  .&&&&&&&  */
0xF6,  /*  .&&.&&&&  */
0xE6,  /*  .&&..&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7E,  /*  .&&&&&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x7C,  /*  ..&&&&&.  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xD6,  /*  .&&.&.&&  */
0xF6,  /*  .&&.&&&&  */
0x7C,  /*  ..&&&&&.  */
0x60,  /*  .....&&.  */
0xE0,  /*  .....&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7E,  /*  .&&&&&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x7C,  /*  ..&&&&&.  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCE,  /*  .&&&..&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x0C,  /*  ..&&....  */
0x38,  /*  ...&&&..  */
0x60,  /*  .....&&.  */
0xC0,  /*  ......&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFF,  /*  &&&&&&&&  */
0xDB,  /*  &&.&&.&&  */
0x99,  /*  &..&&..&  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x10,  /*  ....&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xFE,  /*  .&&&&&&&  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC3,  /*  &&....&&  */
0xC3,  /*  &&....&&  */
0x66,  /*  .&&..&&.  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x66,  /*  .&&..&&.  */
0xC3,  /*  &&....&&  */
0xC3,  /*  &&....&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC3,  /*  &&....&&  */
0xC3,  /*  &&....&&  */
0xC3,  /*  &&....&&  */
0x66,  /*  .&&..&&.  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0xC6,  /*  .&&...&&  */
0xC2,  /*  .&....&&  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x86,  /*  .&&....&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x01,  /*  &.......  */
0x03,  /*  &&......  */
0x07,  /*  &&&.....  */
0x0E,  /*  .&&&....  */
0x1C,  /*  ..&&&...  */
0x38,  /*  ...&&&..  */
0x70,  /*  ....&&&.  */
0xE0,  /*  .....&&&  */
0xC0,  /*  ......&&  */
0x80,  /*  .......&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFF,  /*  &&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x62,  /*  .&...&&.  */
0x60,  /*  .....&&.  */
0x7C,  /*  ..&&&&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x3C,  /*  ..&&&&..  */
0x6C,  /*  ..&&.&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x76,  /*  .&&.&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x70,  /*  ....&&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x78,  /*  ...&&&&.  */
0x6C,  /*  ..&&.&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7E,  /*  .&&&&&&.  */
0x06,  /*  .&&.....  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x4C,  /*  ..&&..&.  */
0x0C,  /*  ..&&....  */
0x3E,  /*  .&&&&&..  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xDC,  /*  ..&&&.&&  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x7C,  /*  ..&&&&&.  */
0x60,  /*  .....&&.  */
0x66,  /*  .&&..&&.  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x6C,  /*  ..&&.&&.  */
0xDC,  /*  ..&&&.&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCE,  /*  .&&&..&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x78,  /*  ...&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x00,  /*  ........  */
0x70,  /*  ....&&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x6C,  /*  ..&&.&&.  */
0x3C,  /*  ..&&&&..  */
0x6C,  /*  ..&&.&&.  */
0xCC,  /*  ..&&..&&  */
0xCE,  /*  .&&&..&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x30,  /*  ....&&..  */
0x78,  /*  ...&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x76,  /*  .&&.&&&.  */
0xFE,  /*  .&&&&&&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x76,  /*  .&&.&&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x76,  /*  .&&.&&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x7C,  /*  ..&&&&&.  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xDC,  /*  ..&&&.&&  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x7C,  /*  ..&&&&&.  */
0x60,  /*  .....&&.  */
0x60,  /*  .....&&.  */
0xF0,  /*  ....&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x76,  /*  .&&.&&&.  */
0xDC,  /*  ..&&&.&&  */
0xCC,  /*  ..&&..&&  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0x1C,  /*  ..&&&...  */
0x70,  /*  ....&&&.  */
0xC0,  /*  ......&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x7E,  /*  .&&&&&&.  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0xD8,  /*  ...&&.&&  */
0x70,  /*  ....&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x38,  /*  ...&&&..  */
0x10,  /*  ....&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xFE,  /*  .&&&&&&&  */
0x6C,  /*  ..&&.&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x38,  /*  ...&&&..  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFC,  /*  ..&&&&&&  */
0xC0,  /*  ......&&  */
0x60,  /*  .....&&.  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0x66,  /*  .&&..&&.  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x70,  /*  ....&&&.  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x0E,  /*  .&&&....  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x70,  /*  ....&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x70,  /*  ....&&&.  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xDC,  /*  ..&&&.&&  */
0x76,  /*  .&&.&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x6E,  /*  .&&&.&&.  */
0x3B,  /*  &&.&&&..  */
0x1B,  /*  &&.&&...  */
0x1B,  /*  &&.&&...  */
0x3B,  /*  &&.&&&..  */
0x6E,  /*  .&&&.&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3E,  /*  .&&&&&..  */
0x63,  /*  &&...&&.  */
0x3F,  /*  &&&&&&..  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x3F,  /*  &&&&&&..  */
0x03,  /*  &&......  */
0x03,  /*  &&......  */
0x02,  /*  .&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7F,  /*  &&&&&&&.  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x03,  /*  &&......  */
0x03,  /*  &&......  */
0x03,  /*  &&......  */
0x03,  /*  &&......  */
0x03,  /*  &&......  */
0x03,  /*  &&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7F,  /*  &&&&&&&.  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7F,  /*  &&&&&&&.  */
0x63,  /*  &&...&&.  */
0x06,  /*  .&&.....  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x06,  /*  .&&.....  */
0x63,  /*  &&...&&.  */
0x7F,  /*  &&&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7E,  /*  .&&&&&&.  */
0x1B,  /*  &&.&&...  */
0x1B,  /*  &&.&&...  */
0x1B,  /*  &&.&&...  */
0x1B,  /*  &&.&&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x3E,  /*  .&&&&&..  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x03,  /*  &&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x6E,  /*  .&&&.&&.  */
0x3B,  /*  &&.&&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3F,  /*  &&&&&&..  */
0x0C,  /*  ..&&....  */
0x1E,  /*  .&&&&...  */
0x33,  /*  &&..&&..  */
0x33,  /*  &&..&&..  */
0x33,  /*  &&..&&..  */
0x1E,  /*  .&&&&...  */
0x0C,  /*  ..&&....  */
0x3F,  /*  &&&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x36,  /*  .&&.&&..  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x7F,  /*  &&&&&&&.  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x36,  /*  .&&.&&..  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x36,  /*  .&&.&&..  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x77,  /*  &&&.&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x06,  /*  .&&.....  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x3E,  /*  .&&&&&..  */
0x33,  /*  &&..&&..  */
0x33,  /*  &&..&&..  */
0x33,  /*  &&..&&..  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3E,  /*  .&&&&&..  */
0x6B,  /*  &&.&.&&.  */
0x6B,  /*  &&.&.&&.  */
0x3E,  /*  .&&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0x3E,  /*  .&&&&&..  */
0x73,  /*  &&..&&&.  */
0x6B,  /*  &&.&.&&.  */
0x67,  /*  &&&..&&.  */
0x3E,  /*  .&&&&&..  */
0x06,  /*  .&&.....  */
0x03,  /*  &&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x06,  /*  .&&.....  */
0x03,  /*  &&......  */
0x03,  /*  &&......  */
0x1F,  /*  &&&&&...  */
0x03,  /*  &&......  */
0x03,  /*  &&......  */
0x06,  /*  .&&.....  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3E,  /*  .&&&&&..  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x63,  /*  &&...&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7F,  /*  &&&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7F,  /*  &&&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7F,  /*  &&&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x06,  /*  .&&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x06,  /*  .&&.....  */
0x03,  /*  &&......  */
0x06,  /*  .&&.....  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x3F,  /*  &&&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x70,  /*  ....&&&.  */
0x58,  /*  ...&&.&.  */
0x58,  /*  ...&&.&.  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x1A,  /*  .&.&&...  */
0x1A,  /*  .&.&&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3F,  /*  &&&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x6E,  /*  .&&&.&&.  */
0x3B,  /*  &&.&&&..  */
0x00,  /*  ........  */
0x6E,  /*  .&&&.&&.  */
0x3B,  /*  &&.&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x1B,  /*  &&.&&...  */
0x1B,  /*  &&.&&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0x80,  /*  .......&  */
0x80,  /*  .......&  */
0x80,  /*  .......&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x78,  /*  ...&&&&.  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x1B,  /*  &&.&&...  */
0x1B,  /*  &&.&&...  */
0x1E,  /*  .&&&&...  */
0x1C,  /*  ..&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1B,  /*  &&.&&...  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0x7C,  /*  ..&&&&&.  */
0x7C,  /*  ..&&&&&.  */
0x7C,  /*  ..&&&&&.  */
0x7C,  /*  ..&&&&&.  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3E,  /*  .&&&&&..  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x3E,  /*  .&&&&&..  */
0x46,  /*  .&&...&.  */
0x66,  /*  .&&..&&.  */
0xF6,  /*  .&&.&&&&  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xCE,  /*  .&&&..&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x70,  /*  ....&&&.  */
0x58,  /*  ...&&.&.  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x7E,  /*  .&&&&&&.  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x1A,  /*  .&.&&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x3C,  /*  ..&&&&..  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x10,  /*  ....&...  */
0x10,  /*  ....&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x4C,  /*  ..&&..&.  */
0x0C,  /*  ..&&....  */
0x1E,  /*  .&&&&...  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0xCE,  /*  .&&&..&&  */
0x7E,  /*  .&&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x63,  /*  &&...&&.  */
0x1C,  /*  ..&&&...  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x1C,  /*  ..&&&...  */
0x63,  /*  &&...&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC3,  /*  &&....&&  */
0xC3,  /*  &&....&&  */
0xC3,  /*  &&....&&  */
0x66,  /*  .&&..&&.  */
0x3C,  /*  ..&&&&..  */
0x7E,  /*  .&&&&&&.  */
0x18,  /*  ...&&...  */
0x7E,  /*  .&&&&&&.  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0x0C,  /*  ..&&....  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x60,  /*  .....&&.  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x44,  /*  ..&...&.  */
0x82,  /*  .&.....&  */
0xBA,  /*  .&.&&&.&  */
0x8A,  /*  .&.&...&  */
0x8A,  /*  .&.&...&  */
0xBA,  /*  .&.&&&.&  */
0x82,  /*  .&.....&  */
0x44,  /*  ..&...&.  */
0x38,  /*  ...&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x36,  /*  .&&.&&..  */
0x36,  /*  .&&.&&..  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x7E,  /*  .&&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xD8,  /*  ...&&.&&  */
0x6C,  /*  ..&&.&&.  */
0x36,  /*  .&&.&&..  */
0x6C,  /*  ..&&.&&.  */
0xD8,  /*  ...&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0x80,  /*  .......&  */
0x80,  /*  .......&  */
0x80,  /*  .......&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFF,  /*  &&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x44,  /*  ..&...&.  */
0x82,  /*  .&.....&  */
0x9A,  /*  .&.&&..&  */
0xAA,  /*  .&.&.&.&  */
0x9A,  /*  .&.&&..&  */
0xAA,  /*  .&.&.&.&  */
0x82,  /*  .&.....&  */
0x44,  /*  ..&...&.  */
0x38,  /*  ...&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFF,  /*  &&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x1B,  /*  &&.&&...  */
0x1B,  /*  &&.&&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x3F,  /*  &&&&&&..  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x3F,  /*  &&&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x1B,  /*  &&.&&...  */
0x0C,  /*  ..&&....  */
0x06,  /*  .&&.....  */
0x13,  /*  &&..&...  */
0x1F,  /*  &&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x1B,  /*  &&.&&...  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x1B,  /*  &&.&&...  */
0x0E,  /*  .&&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x06,  /*  .&&.....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDA,  /*  .&.&&.&&  */
0x02,  /*  .&......  */
0x01,  /*  &.......  */
0x01,  /*  &.......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0xDB,  /*  &&.&&.&&  */
0xDB,  /*  &&.&&.&&  */
0xDB,  /*  &&.&&.&&  */
0xDE,  /*  .&&&&.&&  */
0xD8,  /*  ...&&.&&  */
0xD8,  /*  ...&&.&&  */
0xD8,  /*  ...&&.&&  */
0xD8,  /*  ...&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x60,  /*  .....&&.  */
0xC0,  /*  ......&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0E,  /*  .&&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x36,  /*  .&&.&&..  */
0x6C,  /*  ..&&.&&.  */
0xD8,  /*  ...&&.&&  */
0x6C,  /*  ..&&.&&.  */
0x36,  /*  .&&.&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x07,  /*  &&&.....  */
0xC6,  /*  .&&...&&  */
0x66,  /*  .&&..&&.  */
0x36,  /*  .&&.&&..  */
0x18,  /*  ...&&...  */
0xCC,  /*  ..&&..&&  */
0xE6,  /*  .&&..&&&  */
0xB2,  /*  .&..&&.&  */
0xF8,  /*  ...&&&&&  */
0xC0,  /*  ......&&  */
0xC0,  /*  ......&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x07,  /*  &&&.....  */
0xC6,  /*  .&&...&&  */
0x66,  /*  .&&..&&.  */
0x36,  /*  .&&.&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x76,  /*  .&&.&&&.  */
0xC2,  /*  .&....&&  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0xF8,  /*  ...&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x07,  /*  &&&.....  */
0x0C,  /*  ..&&....  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x37,  /*  &&&.&&..  */
0x18,  /*  ...&&...  */
0xCC,  /*  ..&&..&&  */
0xE6,  /*  .&&..&&&  */
0xB2,  /*  .&..&&.&  */
0xF8,  /*  ...&&&&&  */
0xC0,  /*  ......&&  */
0xC0,  /*  ......&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xDC,  /*  ..&&&.&&  */
0x76,  /*  .&&.&&&.  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFE,  /*  .&&&&&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFC,  /*  ..&&&&&&  */
0x36,  /*  .&&.&&..  */
0x33,  /*  &&..&&..  */
0x33,  /*  &&..&&..  */
0x73,  /*  &&..&&&.  */
0x3F,  /*  &&&&&&..  */
0x33,  /*  &&..&&..  */
0x33,  /*  &&..&&..  */
0x33,  /*  &&..&&..  */
0xF3,  /*  &&..&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x78,  /*  ...&&&&.  */
0xCC,  /*  ..&&..&&  */
0x86,  /*  .&&....&  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x86,  /*  .&&....&  */
0xCC,  /*  ..&&..&&  */
0x78,  /*  ...&&&&.  */
0x60,  /*  .....&&.  */
0xC0,  /*  ......&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0xCC,  /*  ..&&..&&  */
0x0C,  /*  ..&&....  */
0x7C,  /*  ..&&&&&.  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0xCC,  /*  ..&&..&&  */
0xFE,  /*  .&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0xCC,  /*  ..&&..&&  */
0x0C,  /*  ..&&....  */
0x7C,  /*  ..&&&&&.  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0xCC,  /*  ..&&..&&  */
0xFE,  /*  .&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0xCC,  /*  ..&&..&&  */
0x0C,  /*  ..&&....  */
0x7C,  /*  ..&&&&&.  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0xCC,  /*  ..&&..&&  */
0xFE,  /*  .&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xFE,  /*  .&&&&&&&  */
0xCC,  /*  ..&&..&&  */
0x0C,  /*  ..&&....  */
0x7C,  /*  ..&&&&&.  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0xCC,  /*  ..&&..&&  */
0xFE,  /*  .&&&&&&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x66,  /*  .&&..&&.  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3E,  /*  .&&&&&..  */
0x6C,  /*  ..&&.&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xDE,  /*  .&&&&.&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x6C,  /*  ..&&.&&.  */
0x3E,  /*  .&&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xDC,  /*  ..&&&.&&  */
0x76,  /*  .&&.&&&.  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xCE,  /*  .&&&..&&  */
0xDE,  /*  .&&&&.&&  */
0xFE,  /*  .&&&&&&&  */
0xF6,  /*  .&&.&&&&  */
0xE6,  /*  .&&..&&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xDC,  /*  ..&&&.&&  */
0x76,  /*  .&&.&&&.  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x42,  /*  .&....&.  */
0x66,  /*  .&&..&&.  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x66,  /*  .&&..&&.  */
0x42,  /*  .&....&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xB8,  /*  ...&&&.&  */
0x6C,  /*  ..&&.&&.  */
0xE6,  /*  .&&..&&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xCE,  /*  .&&&..&&  */
0x6C,  /*  ..&&.&&.  */
0x3A,  /*  .&.&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0xC3,  /*  &&....&&  */
0xC3,  /*  &&....&&  */
0xC3,  /*  &&....&&  */
0x66,  /*  .&&..&&.  */
0x3C,  /*  ..&&&&..  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x7C,  /*  ..&&&&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x7C,  /*  ..&&&&&.  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0x6C,  /*  ..&&.&&.  */
0x3C,  /*  ..&&&&..  */
0xEC,  /*  ..&&.&&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x6E,  /*  .&&&.&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x62,  /*  .&...&&.  */
0x60,  /*  .....&&.  */
0x7C,  /*  ..&&&&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x62,  /*  .&...&&.  */
0x60,  /*  .....&&.  */
0x7C,  /*  ..&&&&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x62,  /*  .&...&&.  */
0x60,  /*  .....&&.  */
0x7C,  /*  ..&&&&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xDC,  /*  ..&&&.&&  */
0x76,  /*  .&&.&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x62,  /*  .&...&&.  */
0x60,  /*  .....&&.  */
0x7C,  /*  ..&&&&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x62,  /*  .&...&&.  */
0x60,  /*  .....&&.  */
0x7C,  /*  ..&&&&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x38,  /*  ...&&&..  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x62,  /*  .&...&&.  */
0x60,  /*  .....&&.  */
0x7C,  /*  ..&&&&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0x92,  /*  .&..&..&  */
0x90,  /*  ....&..&  */
0xFC,  /*  ..&&&&&&  */
0x12,  /*  .&..&...  */
0x32,  /*  .&..&&..  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x3C,  /*  ..&&&&..  */
0x66,  /*  .&&..&&.  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x06,  /*  .&&.....  */
0x66,  /*  .&&..&&.  */
0x3C,  /*  ..&&&&..  */
0x30,  /*  ....&&..  */
0x60,  /*  .....&&.  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7E,  /*  .&&&&&&.  */
0x06,  /*  .&&.....  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x60,  /*  .....&&.  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7E,  /*  .&&&&&&.  */
0x06,  /*  .&&.....  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7E,  /*  .&&&&&&.  */
0x06,  /*  .&&.....  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7E,  /*  .&&&&&&.  */
0x06,  /*  .&&.....  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x06,  /*  .&&.....  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x66,  /*  .&&..&&.  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x00,  /*  ........  */
0x1C,  /*  ..&&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0E,  /*  .&&&....  */
0x78,  /*  ...&&&&.  */
0x1E,  /*  .&&&&...  */
0x10,  /*  ....&...  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xDC,  /*  ..&&&.&&  */
0x76,  /*  .&&.&&&.  */
0x00,  /*  ........  */
0x76,  /*  .&&.&&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x10,  /*  ....&...  */
0x38,  /*  ...&&&..  */
0x6C,  /*  ..&&.&&.  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xDC,  /*  ..&&&.&&  */
0x76,  /*  .&&.&&&.  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0x7C,  /*  ..&&&&&.  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x7C,  /*  ..&&&&&.  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0xFF,  /*  &&&&&&&&  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x80,  /*  .......&  */
0x7C,  /*  ..&&&&&.  */
0xE6,  /*  .&&..&&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xD6,  /*  .&&.&.&&  */
0xCE,  /*  .&&&..&&  */
0x7C,  /*  ..&&&&&.  */
0x02,  /*  .&......  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x0C,  /*  ..&&....  */
0x18,  /*  ...&&...  */
0x30,  /*  ....&&..  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x0C,  /*  ..&&....  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x18,  /*  ...&&...  */
0x3C,  /*  ..&&&&..  */
0x66,  /*  .&&..&&.  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x00,  /*  ........  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0x66,  /*  .&&..&&.  */
0xDC,  /*  ..&&&.&&  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x30,  /*  ....&&..  */
0x18,  /*  ...&&...  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFC,  /*  ..&&&&&&  */
0xC0,  /*  ......&&  */
0x60,  /*  .....&&.  */
0x3C,  /*  ..&&&&..  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x1E,  /*  .&&&&...  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x7C,  /*  ..&&&&&.  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0xCC,  /*  ..&&..&&  */
0x7C,  /*  ..&&&&&.  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x0C,  /*  ..&&....  */
0x1E,  /*  .&&&&...  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0x00,  /*  ........  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xC6,  /*  .&&...&&  */
0xFC,  /*  ..&&&&&&  */
0xC0,  /*  ......&&  */
0x60,  /*  .....&&.  */
0x3C,  /*  ..&&&&..  */
0x00   /*  ........  */
};
